@@ -27,7 +27,7 @@ def test_aggregate_mean_var_var():
     X = np.append(X_2, X_1, axis=0)
     y = np.append(y_1, y_2, axis=0)
     y = np.append(y, y_2, axis=0)
-    Z = aggregate_mean_var(X, y)
+    Z = aggregate_mean_var(X, y, var_empirical=True)
     assert (Z[0] == np.array([[1.0, 1.0, 1.0], [2.0, 2.0, 2.0]])).all()
     assert (Z[1] == np.array([4.5, 6.0])).all()
     assert (Z[2] == np.array([3.0, 0.0])).all()
